@@ -251,8 +251,8 @@ void KDebugSettingsDialog::slotInsertCategories()
         for (const KdeLoggingCategory &cat : qAsConst(insertCategoriesList)) {
             LoggingCategory loggingCat;
             loggingCat.description = cat.description;
-            loggingCat.logName = cat.logName;
-            loggingCat.defaultCategoryType = KDebugSettingsUtil::convertCategoryTypeFromString(cat.defaultCategory);
+            loggingCat.categoryName = cat.categoryName;
+            loggingCat.defaultSeverityType = KDebugSettingsUtil::convertCategoryTypeFromString(cat.defaultSeverity);
             if (loggingCat.isValid()) {
                 newCategories.append(loggingCat);
             }
